# softnanotools

This repository contains a bunch of tools for different programming applications, mostly in Python. It is used through the [softnanolab](https://softnanolab.org/) research group

## Installation

The package is not yet available on PyPi but will be shortly. For now usage can be done by cloning and using git.

```
git clone https://github.com/softnanolab/softnanotools
pushd softnanotools
pip install .
pytest
popd
```

## Modules

Here is a list of modules with a brief description:

- `notebooks` - Tools for manipulating Jupyter Notebooks
